icalendar.prop package
======================

.. automodule:: icalendar.prop
   :members:
   :show-inheritance:
   :undoc-members:

Submodules
----------

.. toctree::
   :maxdepth: 4

   icalendar.prop.conference
   icalendar.prop.image
